* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Einkommen
* Mikrozensus Scientific Use File 2004

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: eink04.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=2004.

* Versionsnummer des Moduls 'Einkommen'.
COMPUTE vers_ein=5.


*--------------------------------------------   Persoenliches Nettoeinkommen   --------------------------------------------.

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE EF372 (1=112.5) (2=225) (3=400) (4=600) (5=800) (6=1000) (7=1200)
   (8=1400) (9=1600) (10=1850) (11=2150) (12=2450) (13=2750) (14=3050)
   (15=3400) (16=3800) (17=4250) (18=4750) (19=5250) (20=5750) (21=6750)
   (22=8750) (23=14000) (24=27000) (50=-2) (90=0) (99=-1) INTO einkp_1.
EXECUTE.


*------------------------------------   Persoenliches Nettoeinkommen, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkp_1>=0 einkp_2=einkp_1/0.91.
IF einkp_1<0 einkp_2=einkp_1.
EXECUTE.


*--------------------------------------------   Nettoeinkommen des Haushalts   --------------------------------------------.

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE EF539 (0=-2) (1=112.5) (2=225) (3=400) (4=600) (5=800) (6=1000) (7=1200)
   (8=1400) (9=1600) (10=1850) (11=2150) (12=2450) (13=2750) (14=3050)
   (15=3400) (16=3800) (17=4250) (18=4750) (19=5250) (20=5750) (21=6750)
   (22=8750) (23=14000) (24=27000) (50=-2) (99=-1) INTO einkh_1.
EXECUTE.


*------------------------------------   Nettoeinkommen des Haushalts, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkh_1>=0 einkh_2=einkh_1/0.91.
IF einkh_1<0 einkh_2=einkh_1.
EXECUTE.


*---------------------------------------   Zahl der Einkommensbezieher im Haushalt   --------------------------------------.

* Hilfsvariable EF372r=1, wenn Person Einkommen bezieht, Landwirt oder mithelfender
  Familienangehoeriger ist, und EF372r=0, wenn Person kein Einkommen bezieht.
RECODE EF372 (1 THRU 50=1) (90=0) (99=SYSMIS) INTO EF372r.
EXECUTE.

SORT CASES BY hhnr.

AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / MISSING=COLUMNWISE
   / PRESORTED
   / BREAK hhnr
   / ebezh=SUM(EF372r).
EXECUTE.

* Haushalte mit Personen ohne gueltige Angabe beim persoenlichen Einkommen.
RECODE ebezh (SYSMIS=-1) (ELSE=COPY).
EXECUTE.

* Gemeinschaftsunterkuenfte.
IF EF506=3 ebezh=-2.
EXECUTE.


*-------------------------------------------   Ueberwiegender Lebensunterhalt   -------------------------------------------.

RECODE EF338 (1=1) (2=2) (3=4) (4=3) (5 THRU 8=4) INTO ueblu_1.
RECODE EF338 (1=1) (2=2) (3=4) (4=3) (5=5) (6 THRU 8=6) INTO ueblu_2.
RECODE EF338 (1=1) (2=2) (3=4) (4=3) (5=5) (6=6) (7=7) (8=8) INTO ueblu_3.
EXECUTE.


*---------------------------------------   Generierung temporaerer Hilfsvariablen   ---------------------------------------.

* werden spaeter zur Berechnung des Aequivalenzeinkommens und der
  relativen Einkommensposition benoetigt.

* West-Ost.
COMPUTE west=1.
IF EF1>=12 OR EF708=9 west=0.

* Stellung im Haushalt.
COMPUTE sth_t=EF507.
IF EF507=0 sth_t=99.
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES EF372r.
EXECUTE.

