* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Einkommen
* Mikrozensus Scientific Use File 1963

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: eink63.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1963.

* Versionsnummer des Moduls 'Einkommen'.
COMPUTE vers_ein=5.


*--------------------------------------------   Persoenliches Nettoeinkommen   --------------------------------------------.

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE V38 (1=112.5) (2=225) (3=450) (4=700) (5=1000) (6=1500) (7=2700)
   (8=-2) (9=-1) (10=0) (11=-2) INTO einkp_1.
EXECUTE.

* Umrechnung in Euro (1 Euro=1,95583 DM).
IF einkp_1>=0 einkp_1=einkp_1/1.95583.
EXECUTE.


*------------------------------------   Persoenliches Nettoeinkommen, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkp_1>=0 einkp_2=einkp_1/0.274.
IF einkp_1<0 einkp_2=einkp_1.
EXECUTE.


*--------------------------------------------   Nettoeinkommen des Haushalts   --------------------------------------------.

* Schaetzung des Nettoeinkommens des Haushalts aus den Angaben zum persoenlichen Einkommen.
RECODE einkp_1 (-2 THRU -1=SYSMIS) (ELSE=COPY) INTO epr.
SORT CASES BY hhnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / MISSING=COLUMNWISE
   / PRESORTED
   / BREAK hhnr
   / eh1=SUM(epr).
EXECUTE.

* Haushalte mit Personen ohne Angabe beim persoenlichen Einkommen werden auf -1 gesetzt,
  Haushalte mit Landwirten und/oder mithelfenden Familienangehoerigen werden auf -2 gesetzt.
TEMPORARY.
SELECT IF SYSMIS(eh1).
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / eh2=MIN(einkp_1).
EXECUTE.

* Generierung der endgueltigen Variable zum Haushaltseinkommen.
COMPUTE einkh_1=MAX(eh1,eh2).
EXECUTE.

* Gemeinschaftsunterkuenfte.
IF V9=2 einkh_1=-2.
EXECUTE.


*------------------------------------   Nettoeinkommen des Haushalts, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkh_1>=0 einkh_2=einkh_1/0.274.
IF einkh_1<0 einkh_2=einkh_1.
EXECUTE.


*---------------------------------------   Zahl der Einkommensbezieher im Haushalt   --------------------------------------.

* Hilfsvariable V38r=1, wenn Person Einkommen bezieht, Landwirt oder mithelfender
  Familienangehoeriger ist, und V38r=0, wenn Person kein Einkommen bezieht oder
  seit der Befragung 1962 neu zum Haushalt hinzugekommen ist.
RECODE V38 (1 THRU 8=1) (9=SYSMIS) (10=0) (11=SYSMIS) INTO V38r.
EXECUTE.

AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / MISSING=COLUMNWISE
   / PRESORTED
   / BREAK hhnr
   / ebezh=SUM(V38r).
EXECUTE.

* Haushalte mit Personen ohne gueltige Angabe beim persoenlichen Einkommen.
RECODE ebezh (SYSMIS=-1) (ELSE=COPY).
EXECUTE.

* Gemeinschaftsunterkuenfte.
IF V9=2 ebezh=-2.
EXECUTE.


*-------------------------------------------   Ueberwiegender Lebensunterhalt   -------------------------------------------.

RECODE V31 (1=1) (2=4) (3=2) (4 THRU 6=3) INTO ueblu_1.
EXECUTE.


*---------------------------------------   Generierung temporaerer Hilfsvariablen   ---------------------------------------.

* werden spaeter zur Berechnung des Aequivalenzeinkommens und der
  relativen Einkommensposition benoetigt.

* West-Ost.
COMPUTE west=1.

* Stellung im Haushalt.
COMPUTE sth_t=V11.
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES eh1  eh2  epr  V38r.
EXECUTE.

