* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Einkommen
* Mikrozensus Scientific Use File 1987

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: eink87.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1987.

* Versionsnummer des Moduls 'Einkommen'.
COMPUTE vers_ein=5.


*--------------------------------------------   Persoenliches Nettoeinkommen   --------------------------------------------.

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE EF146 (1=225) (2=375) (3=525) (4=700) (5=900) (6=1100) (7=1300)
   (8=1500) (9=1700) (10=1900) (11=2100) (12=2350) (13=2750) (14=3250)
   (15=3750) (16=4250) (17=4750) (18=7500) (50=-2) (99=0) (0=-1) INTO einkp_1.
EXECUTE.

* Umrechnung in Euro (1 Euro=1,95583 DM).
IF einkp_1>=0 einkp_1=einkp_1/1.95583.
EXECUTE.


*------------------------------------   Persoenliches Nettoeinkommen, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkp_1>=0 einkp_2=einkp_1/0.646.
IF einkp_1<0 einkp_2=einkp_1.
EXECUTE.


*--------------------------------------------   Nettoeinkommen des Haushalts   --------------------------------------------.

* Transformation der ordinalen Einkommensangabe in eine metrische Skala
  (Klassen werden durch die jeweilige Klassenmitte ersetzt, unterste Klasse
  wird durch das 0,75-fache des rechten Randes ersetzt, nach oben offene
  Randklasse wird durch das 1,5-fache des linken Randes ersetzt).
RECODE EF182 (1=225) (2=375) (3=525) (4=700) (5=900) (6=1100) (7=1300)
   (8=1500) (9=1700) (10=1900) (11=2100) (12=2350) (13=2750) (14=3250)
   (15=3750) (16=4250) (17=4750) (18=7500) (50, 98=-2) (0=-1) INTO einkh_1.
EXECUTE.

* Umrechnung in Euro (1 Euro = 1,95583 DM).
IF einkh_1>=0 einkh_1=einkh_1/1.95583.
EXECUTE.


*------------------------------------   Nettoeinkommen des Haushalts, preisbereinigt   ------------------------------------.

* Verbraucherpreisindex, 2010=1.
IF einkh_1>=0 einkh_2=einkh_1/0.646.
IF einkh_1<0 einkh_2=einkh_1.
EXECUTE.


*---------------------------------------   Zahl der Einkommensbezieher im Haushalt   --------------------------------------.

* Hilfsvariable EF146r=1, wenn Person Einkommen bezieht, Landwirt oder mithelfender
  Familienangehoeriger ist, und EF146r=0, wenn Person kein Einkommen bezieht.
RECODE EF146 (1 THRU 50=1) (99=0) (0=SYSMIS) INTO EF146r.
EXECUTE.

SORT CASES BY hhnr.

AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / MISSING=COLUMNWISE
   / PRESORTED
   / BREAK hhnr 
   / ebezh=SUM(EF146r).
EXECUTE.

* Haushalte mit Personen ohne gueltige Angabe beim persoenlichen Einkommen.
RECODE ebezh (SYSMIS=-1) (ELSE=COPY).
EXECUTE.

* Gemeinschaftsunterkuenfte.
IF EF27=3 ebezh=-2.
EXECUTE.


*-------------------------------------------   Ueberwiegender Lebensunterhalt   -------------------------------------------.

RECODE EF139 (1=1) (2=2) (3=4) (4=3) (5 THRU 7=4) INTO ueblu_1.
RECODE EF139 (1=1) (2=2) (3=4) (4=3) (5=5) (6,7=6) INTO ueblu_2.
RECODE EF139 (1=1) (2=2) (3=4) (4=3) (5=5) (6=6) (7=8) INTO ueblu_3.
EXECUTE.


*---------------------------------------   Generierung temporaerer Hilfsvariablen   ---------------------------------------.

* werden spaeter zur Berechnung des Aequivalenzeinkommens und der
  relativen Einkommensposition benoetigt.

* West-Ost.
COMPUTE west=1.

* Stellung im Haushalt.
COMPUTE sth_t=EF33.
IF EF33=0 sth_t=99.
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES EF146r.
EXECUTE.

