﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Erwerbstaetigkeit
* Mikrozensus Scientific Use File 2014

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: erwerb14.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=2014.

* Versionsnummer des Moduls 'Erwerbstaetigkeit'.
COMPUTE vers_erw=5.


*-----------------------------   Mithelfende Familienangehoerige oder Gelegeheitstaetigkeit   -----------------------------.

RECODE EF79 (-3,-5,8=0) (1=1) INTO mith.
EXECUTE.


*--------------------------------------------   Geringfuegige Beschaeftigung   --------------------------------------------.

COMPUTE gebes=EF160.
RECODE gebes (1,2,3=1) (8,-2=0) (-3=-2).
IF ((EF215>0 AND EF215<15) AND EF160=8) gebes=2.
EXECUTE.


*---------------------------------------   Erwerbstaetigkeit: Mikrozensus-Konzept   ---------------------------------------.

COMPUTE erw_1=EF29.
RECODE erw_1 (4=3).
EXECUTE.


*-------------------------------------------   Erwerbstaetigkeit: ILO-Konzept   -------------------------------------------.

COMPUTE erw_2=erw_1.
IF (erw_2=2 AND EF276~=1) erw_2=3.
EXECUTE.


*------------------------------------------------   2. Erwerbstaetigkeit   ------------------------------------------------.

COMPUTE zwerw=EF200.
RECODE zwerw (-3,-2,8=0) (1,2=1).
EXECUTE.


*--------------------------------   Normalerweise geleistete Arbeitszeit (Std.) je Woche   --------------------------------.

COMPUTE abstd_1=EF131.
RECODE abstd_1 (56=56.5) (58=58.5) (62=61.5) (63=63.5) (66=66.5) (68=68.5) (72=72.5) (78=77.5)
   (84=85) (90=93.5) (-2,-3=0).
EXECUTE.


*---------------------------------   Tatsaechliche Arbeitszeit (Berichtswoche: Stunden)   ---------------------------------.

COMPUTE abstd_2=EF134.
RECODE abstd_2 (66=66.5) (68=68.5) (72=72.5) (78=77.5) (84=82.5) (85=87) (90=93.5) (-2,-3=0).
EXECUTE.


*-------------------------------------------------   Stellung im Beruf   --------------------------------------------------.

COMPUTE stib_1=EF117.
RECODE stib_1 (1, 2=1) (3=2) (4, 9, 14, 16=3) (5, 12, 17=4) (6=5) (13, 15=6) (-3=-2).
EXECUTE.

COMPUTE stib_2=EF117.
RECODE stib_2 (9=8) (12=5) (13, 15=7) (14=4) (16=9) (17=10) (-3=-2).
EXECUTE.


*------------------------------------------------   Vollzeit oder Teilzeit  -----------------------------------------------.

COMPUTE vztz=EF129.
IF EF129=9 AND (EF131>=1 AND EF131<=34) vztz=2.
IF EF129=9 AND (EF131>=35) vztz=1.
RECODE vztz (-3=-2).
EXECUTE.


*------------------------------------------------   Befristet/Unbefristet   -----------------------------------------------.

COMPUTE frist_1=EF124.
RECODE frist_1 (8=2) (9=-1) (-5,-3=-2).
EXECUTE.

COMPUTE frist_2=EF124.
RECODE frist_2 (8=2) (9=-1) (-5,-3=-2).
IF (EF117=1 OR EF117=2 OR EF117=3) frist_2=3.
EXECUTE.


*------------------------------------------------   Oeffentlicher Dienst   ------------------------------------------------.

COMPUTE oeff=EF121.
RECODE oeff (-3,-2,8=0) (9=-1).
EXECUTE.


*-----------------------------------------------   Beruf nach ISCO-08   -----------------------------------------------.

COMPUTE isco_2=EF541.
RECODE isco_2 (1321,1323=1321) (2521,2529=2521) (3153,3154=3153) (3253,3259=3259)
   (4222,4227=4222) (4413,4419=4419) (7314,7317=7314) (8112,8113=8112) (8131,8132=8131)
   (8151,8152=8151) (8154,8157=8154) (9211,9212=9211) (9999=0) (-5,-3=-2).
EXECUTE.


*-------------------------------------------------   Arbeitslosigkeit   ---------------------------------------------------.

COMPUTE alo_1=0.
IF EF225=1 OR EF225=2 alo_1=1.

COMPUTE alo_2=alo_1.
IF alo_1=1 AND (EF423=0 OR EF424=0) alo_2=2.
IF alo_1=1 AND (EF423=1 OR EF424=1) alo_2=1.
EXECUTE.


*-----------------------------------------------   Beruf nach KldB 2010   -----------------------------------------------.

COMPUTE beruf_3=EF114.
RECODE beruf_3 (0123=0120) (0132=0120) (9999=0) (-5,-3=-2).
EXECUTE.


*-------------------------------------------   Berufsklassifikation: Blossfeld   -------------------------------------------.

* Seit der Neusystematisierung der Berufe in der KldB 2010 sind Fortschreibungen
  fuer die Berufsklassifikation von Blossfeld nicht mehr moeglich.


*-----------------------------------------------------   ISEI-Index   -----------------------------------------------------.

COMPUTE isei=EF541.
RECODE isei
   (0110=61) (0210=52) (0310=29) (1111=69) (1112=79) (1114=71) (1120=70)
   (1211=73) (1212=75) (1213=71) (1219=69) (1221=71) (1222=75) (1223=82)
   (1312=50) (1321=65) (1322=62) (1323=60) (1324=58) (1330=79) (1342=65)
   (1343=65) (1344=65) (1345=65) (1346=65) (1349=65) (1411=44) (1412=44)
   (1420=52) (1431=51) (1439=51) (2111=85) (2112=85) (2113=84) (2114=87)
   (2120=82) (2131=81) (2132=78) (2133=81) (2141=79) (2142=81) (2143=79)
   (2144=77) (2145=82) (2146=79) (2149=79) (2151=81) (2152=81) (2153=81)
   (2161=80) (2162=80) (2163=80) (2164=80) (2165=73) (2166=80) (2211=89)
   (2212=82) (2221=69) (2222=69) (2230=77) (2250=84) (2261=88) (2262=81)
   (2263=75) (2264=68) (2265=65) (2266=75) (2267=75) (2269=75) (2310=85)
   (2320=72) (2330=82) (2341=77) (2351=78) (2352=71) (2353=69) (2354=69)
   (2355=69) (2356=69) (2359=66) (2411=77) (2412=76) (2413=76) (2421=70)
   (2422=73) (2423=69) (2424=70) (2431=74) (2432=74) (2433=74) (2434=74)
   (2511=75) (2512=75) (2513=75) (2514=75) (2519=75) (2521=75) (2522=75)
   (2523=75) (2529=75) (2611=87) (2612=89) (2619=81) (2621=77) (2622=70)
   (2631=81) (2632=83) (2633=84) (2634=86) (2635=71) (2636=72) (2641=73)
   (2642=73) (2643=81) (2651=62) (2652=64) (2653=62) (2654=63) (2655=70)
   (2656=54) (2659=38) (3111=55) (3112=59) (3113=52) (3114=56) (3115=54)
   (3116=60) (3117=63) (3118=51) (3119=51) (3121=38) (3122=41) (3123=38)
   (3131=47) (3132=37) (3133=34) (3134=34) (3135=34) (3141=55) (3142=58)
   (3143=55) (3151=56) (3152=53) (3153=74) (3154=69) (3155=67) (3211=57)
   (3212=57) (3213=49) (3214=55) (3221=56) (3222=52) (3240=25) (3251=48)
   (3252=53) (3253=53) (3254=60) (3255=53) (3256=45) (3257=57) (3258=53)
   (3259=62) (3311=72) (3312=60) (3313=55) (3314=70) (3315=58) (3321=60)
   (3322=57) (3323=56) (3324=61) (3331=55) (3332=57) (3333=60) (3334=62)
   (3339=60) (3341=62) (3342=58) (3343=55) (3344=58) (3351=66) (3352=67)
   (3353=54) (3354=59) (3355=63) (3359=64) (3411=57) (3412=53) (3413=55)
   (3421=51) (3422=51) (3423=51) (3431=50) (3432=58) (3433=50) (3434=50)
   (3435=50) (3511=61) (3512=63) (3513=63) (3514=63) (3521=57) (3522=57)
   (4110=43) (4120=45) (4131=48) (4132=41) (4211=48) (4212=49) (4213=50)
   (4214=50) (4221=49) (4222=39) (4224=39) (4225=39) (4226=39) (4227=39)
   (4311=50) (4312=57) (4321=33) (4322=42) (4323=41) (4411=42) (4412=28)
   (4413=52) (4415=42) (4416=42) (4419=45) (5111=47) (5112=38) (5113=47)
   (5120=25) (5131=25) (5132=25) (5141=31) (5142=31) (5151=25) (5152=32)
   (5153=22) (5163=34) (5164=31) (5165=31) (5169=33) (5211=29) (5221=35)
   (5222=44) (5223=29) (5230=31) (5241=40) (5245=39) (5246=39) (5249=39)
   (5311=25) (5312=25) (5321=27) (5322=22) (5329=27) (5411=46) (5412=52)
   (5413=48) (5414=24) (5419=34) (6111=12) (6112=19) (6113=21) (6121=21)
   (6122=20) (6123=28) (6129=28) (6130=18) (6210=20) (6221=17) (6222=13)
   (7111=34) (7112=23) (7113=24) (7114=22) (7115=27) (7119=27) (7121=22)
   (7122=23) (7123=18) (7124=28) (7125=24) (7126=29) (7127=25) (7131=23)
   (7132=25) (7133=31) (7211=28) (7212=29) (7213=26) (7214=27) (7221=26)
   (7222=33) (7223=29) (7224=34) (7231=31) (7232=48) (7233=32) (7234=31)
   (7311=36) (7312=36) (7313=28) (7314=24) (7315=26) (7316=30) (7317=29)
   (7319=30) (7321=35) (7322=31) (7323=28) (7411=36) (7412=37) (7413=40)
   (7421=44) (7422=37) (7511=21) (7512=24) (7513=27) (7515=34) (7521=22)
   (7522=25) (7523=21) (7531=24) (7532=25) (7533=21) (7534=22) (7535=28)
   (7536=18) (7541=27) (7542=27) (7543=43) (7544=56) (7549=43) (8111=35)
   (8112=25) (8113=36) (8114=26) (8121=30) (8122=22) (8131=29) (8132=31)
   (8141=23) (8142=25) (8143=33) (8151=18) (8152=18) (8153=13) (8154=16)
   (8157=17) (8159=21) (8160=18) (8171=27) (8172=19) (8181=21) (8189=24)
   (8211=28) (8212=24) (8311=46) (8312=30) (8322=30) (8331=27) (8332=26)
   (8341=13) (8342=25) (8343=25) (8344=18) (8350=38) (9111=16) (9112=14)
   (9122=15) (9123=15) (9129=15) (9211=12) (9212=12) (9214=12) (9215=12)
   (9216=12) (9311=15) (9312=18) (9313=15) (9329=16) (9332=17) (9333=18)
   (9334=20) (9412=17) (9612=14) (9613=14) (9621=25) (9623=31) (9629=28)
   (9999=0) (-5, -3=-2).

* Beruecksichtigung der Zusammenfassungen (Zuweisung zum ISEI-Code des arithmetischen Mittelwerts).
IF (EF541=2659 AND EF29=1) isei=40.
IF (EF541=3131 AND EF29=1) isei=46.
IF (EF541=3152 AND EF29=1) isei=54.
IF (EF541=3359 AND EF29=1) isei=63.
IF (EF541=6121 AND EF29=1) isei=22.
IF (EF541=6210 AND EF29=1) isei=19.
IF (EF541=7314 AND EF29=1) isei=26.
IF (EF541=7533 AND EF29=1) isei=23.
IF (EF541=8151 AND EF29=1) isei=16.
IF (EF541=8154 AND EF29=1) isei=18.
IF (EF541=8311 AND EF29=1) isei=45.

IF (erw_1=2 OR erw_1=3) isei=-2.
EXECUTE.


*-------------------------------------------   Bildung der MPS-Berufsvariable   -------------------------------------------.

* Seit der Neusystematisierung der Berufe in der KldB 2010 sind Fortschreibungen
  fuer die Magnitude-Prestigeskala von Wegener nicht mehr moeglich.


*-------------------------------------------------   Wirtschaftssektor   --------------------------------------------------.

COMPUTE sek=EF137.
RECODE sek (11 THRU 99=1) (101 THRU 439=2) (451 THRU 990=3) (-3=-2).
EXECUTE.

