* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Erwerbstaetigkeit
* Mikrozensus Scientific Use File 1999

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: erwerb99.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1999.

* Versionsnummer des Moduls 'Erwerbstaetigkeit'.
COMPUTE vers_erw=5.


*-----------------------------   Mithelfende Familienangehoerige oder Gelegeheitstaetigkeit   -----------------------------.

COMPUTE mith=ef97.
RECODE mith (8=0).
EXECUTE.


*--------------------------------------------   Geringfuegige Beschaeftigung   --------------------------------------------.

COMPUTE gebes=ef98.
RECODE gebes (8=0) (0=-2).
IF (ef99=8) gebes=2.
IF (ef99=0) AND (ef98=1) gebes=2.
EXECUTE.


*---------------------------------------   Erwerbstaetigkeit: Mikrozensus-Konzept   ---------------------------------------.

COMPUTE erw_1=ef504.
RECODE erw_1 (3=2) (4=3).
EXECUTE.


*-------------------------------------------   Erwerbstaetigkeit: ILO-Konzept   -------------------------------------------.

COMPUTE erw_2=ef504.
RECODE erw_2 (4=3).
EXECUTE.


*------------------------------------------------   2. Erwerbstaetigkeit   ------------------------------------------------.

COMPUTE zwerw=ef187.
RECODE zwerw (8=0).
EXECUTE.


*--------------------------------   Normalerweise geleistete Arbeitszeit (Std.) je Woche   --------------------------------.

COMPUTE abstd_1=ef141.
RECODE abstd_1 (50=52) (55=57) (60=62) (65=67) (70=72) (75=77) (80=82)
   (85=87) (90=93.5).
EXECUTE.


*---------------------------------   Tatsaechliche Arbeitszeit (Berichtswoche: Stunden)   ---------------------------------.

COMPUTE abstd_2=ef143.
RECODE abstd_2 (65=67) (70=72) (75=77) (80=82) (85=87)
   (90=93.5) (99=0).
EXECUTE.


*-------------------------------------------------   Stellung im Beruf   --------------------------------------------------.

COMPUTE stib_1=EF127.
RECODE stib_1 (1, 2=1) (3=2) (4, 9, 10=3) (5, 11=4) (6=5) (7, 8=6) (0=-2).
EXECUTE.

COMPUTE stib_2=EF127.
RECODE stib_2 (7, 8=7) (9=8) (10=9) (11=10) (0=-2).
EXECUTE.


*------------------------------------------------   Vollzeit oder Teilzeit  -----------------------------------------------.

COMPUTE vztz=ef138.
RECODE vztz  (0=-2).
EXECUTE.


*------------------------------------------------   Befristet/Unbefristet   -----------------------------------------------.

COMPUTE frist_1=ef134.
RECODE frist_1 (9=-1) (0, 3=-2).
EXECUTE.

COMPUTE frist_2=ef134.
RECODE frist_2 (9=-1) (0=-2).
EXECUTE.


*------------------------------------------------   Oeffentlicher Dienst   ------------------------------------------------.

COMPUTE oeff=ef130.
RECODE oeff (0, 8=0) (9=-1).
IF (erw_1=2 OR erw_1=3) oeff=0.
EXECUTE.


*-----------------------------------------------   Beruf nach ISCO-88 COM   -----------------------------------------------.

COMPUTE isco_1=ef683.
RECODE isco_1 (212, 213=213) (333,334=334) (811,812=811) (823, 824, 825=823)
   (521,522,614,615,834,911,913,999=-1).
IF (erw_1=2 OR erw_1=3) isco_1=-2.
IF (ef738=0) isco_1=-2.
EXECUTE.


*-------------------------------------------------   Arbeitslosigkeit   ---------------------------------------------------.

COMPUTE alo_1=ef214.
RECODE alo_1  (8=0).
EXECUTE.

COMPUTE alo_2=alo_1.
RECODE alo_2 (1=2).
IF (ef215=1) alo_2=1. 
IF (alo_1=1 AND EF215=0) alo_2=3.
EXECUTE.


*-----------------------------------------------   Beruf nach KldB 1992   -----------------------------------------------.

COMPUTE beruf_2=ef128.
RECODE beruf_2 (071,072=071) (101,102,112=101) (172,173=172) (212,213=212)
   (224,225,229,231,233,234,235=225) (290,291,292,293,294,295=290) (308,309=308)
   (331,332=331) (353,354,359=353) (373,374,376,378=371) (421,422,423,424=421) (471,472=471)
   (480,481,484=481) (505,506=505) (605,606=605) (625,626,629=625) (721,723,724=721)
   (731,732=732) (880,887=880) (981,982,983=981) (0=-2).
EXECUTE.


*-------------------------------------------   Berufsklassifikation: Blossfeld   -------------------------------------------.

COMPUTE bk=ef128.
RECODE bk (11,12,13,14,23,24,51,53,61,62=1)
   (70,71,72,80,101,121,131,135,141,145,150,152,153,161,162,
   164,179,181,185,191,194,211,212,213,222,224,225,231,234,241,
   245,313,321,322,323,332,341,344,352,353,358,359,361,373,376,393,
   431,435,440,442,443,460,461,463,465,466,471,472,482,486,488,
   512,521,522,523,531,540,544,545,546,549,550=2)
   (142,171,173,174,175,178,201,220,221,250,254,255,256,259,261,
   264,265,266,267,268,269,270,273,274,276,278,281,282,283,287,
   290,292,293,300,302,305,307,308,310,311,312,315,316,317,
   318,331,351,371,374,391,392,401,411,421,423,441,480,481,483,
   485,487,491,492,501,502,505,506,510,511,541=3)
   (303,304,620,621,622,623,624,625,626,627,628,629,631,632,633,634,
   641,642,651,652,721,857=4)
   (31,52,600,601,602,603,604,605,606,607,608,609,611,612,726,883=5)
   (685,686,706,713,714,715,716,723,741,742,743,744,791,792,793,
   794,795,796,805,838,911,912,914,915,923,931,934,935,936,937=6)
   (172,675,704,705,711,712,801,802,803,804,812,814,831,832,833,
   834,835,836,837,851,852,854,855,856,858,859,894,901,902,921=7)
   (821,822,823,853,861,862,863,864,865,866,867,868,869,870,873,
   874,875,876,878,879=8)
   (811,813,841,842,843,844,871,872,880,881,882,884,885,886,887,891=9)
   (660,661,662,663,687,689,731,735,773,782,783,784,789=10)
   (670,671,672,673,674,676,677,678,683,691,692,695,701,702,
   703,771,772,774,775,776,777,778,779,780,785,786,787,788=11)
   (750,751,753,754,755,756,757,761,763,764,765=12)
   (0=-2) (ELSE=0).
IF (erw_1=2 OR erw_1=3) bk=-2.
EXECUTE.


*-----------------------------------------------------   ISEI-Index   -----------------------------------------------------.

COMPUTE isei=ef683.
RECODE isei
   (100=55) (110=70) (111=77) (112=77) (113=66) (114=58) (120=68)
   (121=70) (122=67) (123=61) (124=58) (125=64) (130=51) (131=51)
   (200=70) (210=69) (211=74) (212=71) (213=71) (214=73) (220=80)
   (221=78) (222=85) (223=43) (230=69) (231=77) (232=69) (233=66)
   (234=66) (235=66) (240=68) (241=69) (242=85) (243=65) (244=65)
   (245=61) (246=53) (247=68) (300=54) (310=50) (311=49) (312=52)
   (313=52) (314=57) (315=50) (320=48) (321=50) (322=55) (323=38)
   (324=49) (330=38) (331=38) (332=38) (333=38) (334=38) (340=55)
   (341=55) (342=55) (343=54) (344=56) (345=56) (346=43) (347=52)
   (348=38) (400=45) (410=45) (411=51) (412=51) (413=36) (414=39)
   (419=39) (420=49) (421=48) (422=52) (500=40) (510=38) (511=34)
   (512=32) (513=25) (514=30) (515=43) (516=47) (520=43) 
   (522=43) (523=37) (600=23) (610=23) (611=23) (612=23) (613=23)
   (614=22) (620=16) (621=16) (700=34) (710=31) (711=30)
   (712=30) (713=34) (714=29) (720=34) (721=31) (722=35) (723=34)
   (724=40) (730=34) (731=38) (732=28) (733=29) (734=40) (740=33)
   (741=30) (742=33) (743=36) (744=31) (750=42) (751=42) (752=38)
   (753=26) (800=31) (810=30) (811=35) (812=30) (813=24.5) 
   (815=35) (816=32) (817=26) (820=32) (821=36) (822=30) (823=29.5)
   (825=38) (826=30) (827=29) (828=31) (829=26) (830=32)
   (831=36) (832=34) (833=26) (834=32) (840=24) (900=20) (910=25)
   (912=28) (913=16) (914=23) (915=27) (916=23) (920=16)
   (921=16) (930=23) (931=21) (932=20) (933=29) (ELSE=0).
IF (erw_1=2 OR erw_1=3) isei=-2.
IF (ef738=0) isei=-2.
EXECUTE.


*-------------------------------------------   Bildung der MPS-Berufsvariable   -------------------------------------------.

COMPUTE mps=ef128.
RECODE mps (0=-2) (11=35.1)(12=42.7)(13=30.1)(14=30.0)(23=41.1)(24=33.4)
   (31=82.3)(51=32.4)(52=64.9)(53=52.9)(61=64.0)(62=31.8)
   (70=35.3)(71=35.3)(72=46.1)(80=35.9)(101=39.2) 
   (121=31.7)(131=35.6)(135=33.1)(141=36.8)(142=49.1)(145=34.6)
   (150=32.8)(152=32.8)(153=32.8)(161=32.9)(162=31.5)(164=32.1)
   (171=51.2)(172=50.3)(173=50.3)(174=48.9)(175=42.5)
   (178=39.5)(179=39.5)(181=31.2)(185=35.3)(191=33.4)
   (194=32.1)(201=35.0)(211=31.9)(212=32.1)(213=32.9)(220=32.0) (221=35.9)
   (222=33.5)(224=36.1)(225=32.5)(231=35.8)(234=35.9)
   (241=35.4)(245=35.2)(250=37.5)(254=38.8)(255=37.5)
   (256=38.8)(259=38.8)(261=39.3)(264=44.2)(265=39.3)(266=43.6)(267=44.2)
   (268=44.2)(269=44.2)(270=43.6)(273=40.8)(274=37.4)(276=43.6)(278=43.6)
   (281=46.0)(282=42.8)(283=49.1)(287=39.3)(290=41.6)(292=43.5)(293=41.6)
   (300=47.4)(302=54.0)(303=64.9)(304=72.2)(305=45.2)
   (307=47.4)(308=51.0)(310=47.7)(311=47.7)(312=48.6)(313=44.3)
   (315=50.2)(316=50.2)(317=50.2)(318=47.7)(321=35.6)(322=38.5)(323=31.7)
   (331=31.5)(332=32.6)(341=35.2)(344=34.7)(351=48.0)(352=33.5)
   (353=33.6)(358=34.2)(359=35.4)(361=35.0)(371=43.2)
   (373=30.3)(374=40.7)(376=42.7)(391=51.6)(392=52.5)(393=33.0)
   (401=52.3)(411=45.1)(421=42.7)(423=37.2)(431=41.1)(435=41.1)
   (440=39.2)(441=39.2)(442=39.2)(443=37.2)(460=44.2)(461=32.1)(463=32.7)
   (465=33.1)(466=44.2)(471=30.3)(472=30.2)(480=45.4)(481=40.8)(482=42.8)
   (483=47.8)(485=40.9)(486=39.2)(487=41.7)(488=38.7)(491=49.6)
   (492=35.4)(501=42.5)(502=41.4)(505=42.5)(506=37.3)(510=44.2)(511=44.2)
   (512=41.8)(521=43.1)(522=32.1)(523=43.1)(531=31.0)(540=34.2)
   (541=42.5)(544=32.2)(545=32.5)(546=33.1)(549=34.2)(550=36.1)(600=88.3)
   (601=103.5)(602=89.6)(603=111.7)(604=85.7)(605=91.0)(606=104.6)(607=88.3)
   (608=88.3)(609=111.7)(611=123.9)(612=125.2)(620=67.5)(621=69.7)(622=61.8)
   (623=71.2)(624=53.4)(625=91.0)(626=72.1)(627=67.7)(628=67.5)(629=67.5)
   (631=60.7)(632=50.2)(633=53.1)(634=53.1)(641=52.7)(642=52.7)(651=63.9)
   (652=63.9)(660=51.1)(661=51.1)(662=51.1)(663=51.1)(670=78.0)(671=78.0)
   (672=78.0)(673=78.0)(674=80.7)(675=69.7)(676=78.0)(677=78.0)(678=78.0)
   (683=80.7)(685=51.6)(686=46.1)(687=68.8)(689=68.8)(691=74.1)(692=68.9)
   (695=71.0)(701=61.0)(702=69.2)(703=71.9)(704=80.6)
   (705=54.2)(706=47.8)(711=50.1)(712=49.5)(713=51.8)(714=35.1)(715=35.1)
   (716=35.5)(721=80.3)(723=48.0)(726=79.8)(731=50.4)
   (735=50.3)(741=37.1)(742=31.1)(743=36.2)(744=31.5)(750=101.3)(751=101.3)
   (753=106.0)(754=106)(755=90.1)(756=90.1)(757=90.1)(761=153.5)(763=80.0)
   (764=84.7)(765=84.7)(771=68.9)(772=64.7)(773=53.3)(774=79.6)(775=79.6)
   (776=79.6)(777=79.6)(778=79.6)(779=79.6)(780=60.4)(782=53.2)(783=53.3)
   (784=42.9)(785=60.4)(786=60.4)(787=60.4)(788=60.4)(789=53.2)
   (791=46.2)(792=36.5)(793=39.1)(794=36.1)(795=67.6)(796=39.1)(801=63.0)
   (802=52.9)(803=53.1)(804=61.1)(805=51.7)(811=138.2)(812=84.7)(813=145.7)
   (814=53.5)(821=85.4)(822=80.9)(823=80.3)(831=78.1)(832=80.4)(833=69.1)
   (834=69.1)(835=54.1)(836=53.6)(837=64.1)(838=56.7)(841=191.3) 
   (842=216)(843=138.9)(844=207.2)(851=80.8)(852=61.2)(853=51.5)(854=43.1)
   (855=68.9)(856=52.9)(857=53.2)(858=68.9)(859=61.2)(861=62.3)(862=62.3)
   (863=62.3)(864=62.3)(865=62.3)(866=62.3)(867=62.3)(868=80.3)(869=62.3)
   (870=120.0)(871=152.5)(872=132.1)(873=120.0)(874=104.6)(875=80.9)
   (876=67.6)(878=71.4)(879=71.4)(880=122.2)(881=135.7)(882=122.2)(883=139.8)
   (884=135.7)(885=122.2)(886=135.7)(887=135.7)(891=122.0)(894=54.7)
   (901=60.6)(902=44.4)(911=53.9)(912=38.8)(914=53.9)(915=38.5)(921=64.4)
   (923=37.4)(931=45.4)(934=32.3)(935=32.6)(936=32.5)(937=32.3) (ELSE=0). 
IF (erw_1=2 OR erw_1=3) mps=-2.
EXECUTE.


*-------------------------------------------------   Wirtschaftssektor   --------------------------------------------------.

COMPUTE sek=ef129.
RECODE sek (11 THRU 145=1) (151 THRU 455=2) (501 THRU 990=3) (0=-2).
EXECUTE.

