﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Haushalt, Familie und Lebensform
* Mikrozensus Scientific Use File 1964

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: fam64.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1964.

* Versionsnummer des Moduls 'Haushalt und Familie'.
COMPUTE vers_fam=5.


*------------------------------------------------------   Haushalt   ------------------------------------------------------.

* Stellung im Haushalt.
RECODE V11 (1,2=1) (3=2) (4,5,7=3) (6=4) (8=-2) INTO sthh_1.
EXECUTE.

* 1. Person im Privathaushalt.
RECODE sthh_1 (-2=99) (ELSE=COPY) INTO sthh_temp.
SORT CASES BY hhnr sthh_temp gesch (A) alter (D).
IF hhnr~=LAG(hhnr) ephh=1.
EXECUTE.
IF $CASENUM=1 ephh=1.
RECODE ephh (SYSMIS=0).

* Hilfsvariable h=1 fuer jede Person.
COMPUTE h=1.

* Hilfsvariable i=1, wenn Alter unter 3 Jahre (sonst i=0).
COMPUTE i=0.
IF (alter<3) i=1.

* Hilfsvariable j=1, wenn Alter unter 15 Jahre (sonst j=0).
COMPUTE j=0.
IF (alter<15) j=1.
IF (bpriv=2) h=0.
IF (bpriv=2) i=0.
IF (bpriv=2) j=0.

* Anzahl der Personen / Kinder unter 3 bzw. 15 Jahre im Haushalt.
SORT CASES BY hhnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / hhanz=SUM (h)
   / hhk_1=SUM (i)
   / hhk_2=SUM (j).
IF (bpriv=2) hhanz=-2.
IF (bpriv=2) hhk_1=-2.
IF (bpriv=2) hhk_2=-2.


*-------------------------------------------------   Eheschliessungsjahr   ------------------------------------------------.

IF (V16>78) ehej=V16+1800.
IF (V16<77) ehej=V16+1900.
IF (V16=77 OR V16=78) ehej=-1.
IF (V15~=2) ehej=-2.
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES sthh_temp h i j.
EXECUTE.

