﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Methodische Variablen
* Mikrozensus Scientific Use File 1969

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: methvar69.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

* Erhebungsjahr.
COMPUTE jahr=1969.

* Versionsnummer des Moduls 'Methodische Variablen'.
COMPUTE vers_met=5.


*---------------------------------------------------------   ID   ---------------------------------------------------------.

* Identifikationsnummer, fortlaufend nach Reihenfolge im Ausgangsdatensatz.
COMPUTE idnr=(1969000000+$CASENUM).
EXECUTE.


*----------------------------------------------   Zweite Erwerbstaetigkeit   ----------------------------------------------.

* Identifikation von Faellen mit zweiter Erwerbstaetigkeit.
COMPUTE zwid=$CASENUM.
SORT CASES BY zwid (D).
COMPUTE zwerw=LAG(V28).
SORT CASES BY zwid (A).
RECODE zwerw (SYSMIS, 1, 2=0).
IF (zwerw=3 AND V28=1) zwerw=1.
EXECUTE.

* Ausschluss von Duplikaten mit Angaben zur zweiten Erwerbstaetigkeit.
SELECT IF V28=1 OR V28=2.
EXECUTE.


*----------------------------------------------   Haushaltsidentifikation   -----------------------------------------------.

* Haushaltsnummer, fortlaufend
  (eigene Nummer fuer ergaenzte Haushalte).
SORT CASES BY V5 V6 V66.
IF $CASENUM=1 hhnr=1.
IF V5~=LAG(V5) OR V6~=LAG(V6) OR V66~=LAG(V66) hhnr=hhnr+1.
LEAVE hhnr.
EXECUTE.


*-------------------------------------------   Ergaenzung bekannter Ausfaelle   -------------------------------------------.

RECODE V66 (1=1) (ELSE=0) INTO erg.
EXECUTE.


*------------------------------------   Anpassung an die Bevoelkerungsfortschreibung   ------------------------------------.

*--- Identifikationsschema 1 ---.
*--- Identifikation von Duplikaten ueber Abgleich von V7 ---.

* in V67 als gedoppelt ausgewiesene Personen haben identische Auspraegung
  in V7, so dass auch diese hier erfasst werden.

* Markierung der Personen mit identischer Auspraegung in V7
  (sum_1 gibt deren Anzahl wieder).
COMPUTE p=1.
SORT CASES BY hhnr V7.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr V7
   / sum_1=SUM(p).
EXECUTE.

* jeweils erste Person wird als Originalfall markiert.
IF sum_1>1 AND (hhnr~=LAG(hhnr) OR V7~=LAG(V7)) master_1=1.

* alle weiteren Personen werden als Duplikat markiert.
IF sum_1>1 AND SYSMIS(master_1) master_1=2.
EXECUTE.


*--- Identifikationsschema 2 ---.
*--- Identifikation von Duplikaten ueber Abgleich aller uebrigen Variablen mit gueltigen Angaben ---.

* Markierung der Personen mit identischer Auspraegung in allen uebrigen Variablen
  (sum_2 gibt deren Anzahl wieder).
SORT CASES BY hhnr V8 V9 V10 V11 V12 V13 V14 V15 V16 V17 V18 V19 V20 V21 V22
   V23 V24 V25 V26 V27 V28 V29 V30 V31 V32 V33 V34 V35 V36 V37 V38 V39 V40 V41
   V42 V43 V44 V45 V48 V50 V51 V52 V55 V56 V57 V58 V59 V62 V63 V64 V65 V68 V69
   V70 V71 V72.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr V8 V9 V10 V11 V12 V13 V14 V15 V16 V17 V18 V19 V20 V21 V22 V23 V24
     V25 V26 V27 V28 V29 V30 V31 V32 V33 V34 V35 V36 V37 V38 V39 V40 V41 V42 V43 V44
     V45 V48 V50 V51 V52 V55 V56 V57 V58 V59 V62 V63 V64 V65 V68 V69 V70 V71 V72
   / sum_2=SUM(p).
EXECUTE.

* jeweils erste Person wird als Originalfall markiert (da Uebereinstimmung in allen Variablen
  vorliegt, ist Wahl des Originalfalls beliebig).
IF (hhnr~=LAG(hhnr) OR ((hhnr=LAG(hhnr) AND (V8~=LAG(V8) OR V9~=LAG(V9)
   OR V10~=LAG(V10) OR V11~=LAG(V11) OR V12~=LAG(V12) OR V13~=LAG(V13)
   OR V14~=LAG(V14) OR V15~=LAG(V15) OR V16~=LAG(V16) OR V17~=LAG(V17)
   OR V18~=LAG(V18) OR V19~=LAG(V19) OR V20~=LAG(V20) OR V21~=LAG(V21)
   OR V22~=LAG(V22) OR V23~=LAG(V23) OR V24~=LAG(V24) OR V25~=LAG(V25)
   OR V26~=LAG(V26) OR V27~=LAG(V27) OR V28~=LAG(V28) OR V29~=LAG(V29)
   OR V30~=LAG(V30) OR V31~=LAG(V31) OR V32~=LAG(V32) OR V33~=LAG(V33)
   OR V34~=LAG(V34) OR V35~=LAG(V35) OR V36~=LAG(V36) OR V37~=LAG(V37)
   OR V38~=LAG(V38) OR V39~=LAG(V39) OR V40~=LAG(V40) OR V41~=LAG(V41)
   OR V42~=LAG(V42) OR V43~=LAG(V43) OR V44~=LAG(V44) OR V45~=LAG(V45)
   OR V48~=LAG(V48) OR V50~=LAG(V50) OR V51~=LAG(V51) OR V52~=LAG(V52)
   OR V55~=LAG(V55) OR V56~=LAG(V56) OR V57~=LAG(V57) OR V58~=LAG(V58)
   OR V59~=LAG(V59) OR V62~=LAG(V62) OR V63~=LAG(V63) OR V64~=LAG(V64)
   OR V65~=LAG(V65) OR V68~=LAG(V68) OR V69~=LAG(V69) OR V70~=LAG(V70) 
   OR V71~=LAG(V71) OR V72~=LAG(V72))))) AND sum_2>1 master_2=1.

* alle weiteren Personen werden als Duplikat markiert.
IF sum_2>1 AND SYSMIS(master_2) master_2=2.
EXECUTE.


*--- Zusammenfuehrung beider Identifikationsschemata ---.

* Kennzeichnung der nach Identifikationsschema 1 zusammengehoerenden Personen
  mit einer einheitlichen Nummer (die V7 entspricht).
IF sum_1>1 nr_1=V7.

* Kennzeichnung der nach Identifikationsschema 2 zusammengehoerenden Personen
  mit einer einheitlichen Nummer (die nicht zum Auspraegungsspektrum von V7 gehoert).
IF hhnr~=LAG(hhnr) nr_2=100.
IF master_2=1 nr_2=nr_2+1.
LEAVE nr_2.
EXECUTE.
IF sum_2=1 nr_2=$SYSMIS.
EXECUTE.

* Nummern (V7) aller nach Schema 2 identifizierten Personen werden in neue Variablen geschrieben,
  auf alle Mitglieder des jeweiligen Haushalts uebertragen und mit deren Nummern (V7) abgeglichen.

SORT CASES BY hhnr V7.

* fortlaufende Nummer der Person im Haushalt (zur Bildung einer Schleife).
COMPUTE p_nr=1.
DO IF hhnr=LAG(hhnr).
+   COMPUTE p_nr=LAG(p_nr)+1.
END IF.
EXECUTE.

* Nummern aller nach Schema 2 identifizierten Personen werden in neue Variablen geschrieben
  (wobei es maximal 18 Personen pro Haushalt gibt).
VECTOR V7_p(18) nr_p(18).
LOOP #i=1 TO 18.
+   IF p_nr=#i AND nr_2>=1 V7_p(#i)=V7.
+   IF p_nr=#i AND nr_2>=1 nr_p(#i)=nr_2.
END LOOP.
EXECUTE.

* Nummern werden auf alle Mitglieder des jeweiligen Haushalts uebertragen.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / V7p1 TO V7p18=MAX(V7_p1 TO V7_p18)
   / nrp1 TO nrp18=MAX(nr_p1 TO nr_p18).
EXECUTE.

* Nummer jeder Person im Haushalt wird mit den Nummern aller nach Schema 2 identifizierten
  Personen abgeglichen, im Fall der Uebereinstimmung wird der neuen Variable 'nr' die Nummer
  der entsprechenden Person zugewiesen.
VECTOR V7p=V7p1 TO V7p18 / nrp=nrp1 TO nrp18.
LOOP #i=1 TO 18.
+   IF V7=V7p(#i) nr=nrp(#i).
END LOOP.
EXECUTE.

* Personen, die nur nach Identifikationsschema 1 mit anderen zusammengehoeren.
IF SYSMIS(nr) AND nr_1>=1 nr=nr_1.

* Anzahl der identischen Personen.
SORT CASES BY hhnr nr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr nr
   / sum=NU(nr).
EXECUTE.

* Identifikation von Originalfaellen und Duplikaten.

* jeweils erste Person wird als Originalfall markiert (nach vorheriger Sortierung nach master_1).
RECODE master_1 (SYSMIS=3) (ELSE=COPY).
SORT CASES BY hhnr nr master_1.
RECODE nr (SYSMIS=0) (ELSE=COPY).
IF nr>=1 AND (hhnr~=LAG(hhnr) OR nr~=LAG(nr)) master=1.
EXECUTE.

* alle weiteren Personen werden als Duplikat markiert.
IF nr>=1 AND SYSMIS(master) master=2.
EXECUTE.


*----------------------------------------------   Ausschluss der Duplikate   ----------------------------------------------.

SELECT IF SYSMIS(master) OR master=1.
EXECUTE.


*---------------------------------------   Gewichtungs- und Hochrechnungsfaktoren   ---------------------------------------.

* Personengewichtungsfaktor
  (Originalfaelle werden mit dem Faktor ihrer Vervielfachung gewichtet; zu streichende Faelle
  werden mit 0, wenn sie zusaetzlich vervielfacht wurden mit sum-1 gewichtet; alle uebrigen Faelle
  werden mit 1 gewichtet).
COMPUTE pge=1.
IF master=1 pge=sum.
IF V67=2 AND SYSMIS(master) pge=0.
IF V67=2 AND master=1 pge=sum-1.
EXECUTE.

* Haushaltsgewichtungsfaktor
  (arithmetisches Mittel der Personengewichtungsfaktoren aller Haushaltsmitglieder).
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / hge=MEAN(pge).
EXECUTE.

* Personengewichtungs- und Hochrechnungsfaktor.
COMPUTE pgeh=pge*100.
EXECUTE.

* Haushaltsgewichtungs- und Hochrechnungsfaktor.
COMPUTE hgeh=hge*100.
EXECUTE.


*------------------------------------   Stichprobenkennzeichnung und Erhebungsmodus   -------------------------------------.

* nicht relevant / nicht ausgewiesen.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES master  master_1  master_2  nr  nr_1  nr_2   p  p_nr  sum  sum_1  sum_2
   V7_p1 TO V7_p18  nr_p1 TO nr_p18  V7p1 TO V7p18  nrp1 TO nrp18.
EXECUTE.

