* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Methodische Variablen
* Mikrozensus Scientific Use File 1985

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: methvar85.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

* Erhebungsjahr.
COMPUTE jahr=1985.

* Versionsnummer des Moduls 'Methodische Variablen'.
COMPUTE vers_met=5.


*---------------------------------------------------------   ID   ---------------------------------------------------------.

* Identifikationsnummer, fortlaufend nach Reihenfolge im Ausgangsdatensatz.
COMPUTE idnr=(1985000000+$CASENUM).
EXECUTE.


*----------------------------------------------   Haushaltsidentifikation   -----------------------------------------------.

* Haushaltsnummer, fortlaufend.
SORT CASES BY EF1 EF3 EF4.
IF $CASENUM=1 hhnr=1.
IF EF1~=lag(EF1) OR EF3~=lag(EF3) OR EF4~=lag(EF4) hhnr=hhnr+1.
LEAVE hhnr.
EXECUTE.


*------------------------------------   Anpassung an die Bevoelkerungsfortschreibung   ------------------------------------.

* Markierung der Originalfaelle.
COMPUTE master=0.
IF (EF252=0) master=1.
EXECUTE.


*----------------------------------------------   Ausschluss der Duplikate   ----------------------------------------------.

SELECT IF EF252~=1.
EXECUTE.


*---------------------------------------   Gewichtungs- und Hochrechnungsfaktoren   ---------------------------------------.

* Personengewichtungsfaktor
  (Originalfaelle werden mit dem Faktor ihrer Vervielfachung, zu streichende Faelle, gedoppelte fiktive und gestrichene Soldaten
  mit dem Faktor 0 und alle uebrigen Faelle mit dem Faktor 1 gewichtet. 
COMPUTE pge=1.
IF master=1 pge=EF254.
IF (EF252=2 OR EF252>=3) pge=0.
EXECUTE.

* Haushaltsgewichtungsfaktor
  (arithmetisches Mittel der Personengewichtungsfaktoren aller Haushaltsmitglieder).
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / hge=MEAN(pge).
EXECUTE.

* Personengewichtungs- und Hochrechnungsfaktor.
COMPUTE pgeh=pge*100/0.7.
EXECUTE.

* Haushaltsgewichtungs- und Hochrechnungsfaktor.
COMPUTE hgeh=hge*100/0.7.
EXECUTE.


*------------------------------------   Stichprobenkennzeichnung und Erhebungsmodus   -------------------------------------.

* nicht relevant / nicht ausgewiesen.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES master.
EXECUTE.

